#!/bin/bash
set -e
TITLE="Haystack Situations"
ITEMTITLE="Haystack Situation #"
OUT="/home/claude/www/mathr-co-uk/haystack-situations/"
WWW="http://mathr-co-uk/haystack-situations/"
BIN="/home/claude/opt/bin/haystack-situations"
LOG="/home/claude/opt/var/log/haystack-situations.log"
OLD="$(date --date='1 week ago' +'%Y%m%d')"
NEW="$(date                     +'%Y%m%d')"
(
  cd "${OUT}"
  rm -f "${OLD}.pdf"
  "${BIN}" "${NEW}"
  (
    cat <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<rss version="2.0" xmlns:atom="http://www.w3.org/2005/Atom">
<channel>
<title>${TITLE}</title>
<link>${WWW}</link>
<description>Explorations of icosahedral rotational symmetry.</description>
<ttl>1440</ttl>
<atom:link href="${WWW}index.rss" rel="self" type="application/rss+xml" />
<image>
<url>${WWW}${NEW}.png</url>
<title>${TITLE}</title>
<link>${WWW}</link>
<width>144</width>
<height>204</height>
</image>
EOF
    for f in $(ls -1 -r ????????.pdf)
    do
      NUMBER="${f%.pdf}"
      SIZE="$(stat -c '%s' "${f}")"
      DATE="$(date --rfc-822 -r "${f}")"
      cat <<EOF
<item>
<title>${ITEMTITLE}${NUMBER}</title>
<pubDate>${DATE}</pubDate>
<description>&lt;img alt="${ITEMTITLE}${NUMBER}" src="${WWW}${NUMBER}.png"&gt;</description>
<link>${WWW}${NUMBER}.png</link>
<guid>${WWW}${NUMBER}.png</guid>
<enclosure url="${WWW}${NUMBER}.pdf" length="${SIZE}" type="application/pdf" />
</item>
EOF
    done
    cat <<EOF
</channel></rss>
EOF
  ) >index.rss
  (
    cat <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head profile="http://www.w3.org/2005/10/profile">
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<title>Haystack Situations</title>
<link rel="alternate" type="application/rss+xml" href="index.rss" title="Hackstack Situations feed" />
<link rel="shortcut icon" href="../blog/favicon.ico" />
<link rel="icon" type="image/png" href="../blog/favicon.png" />
<style type="text/css">
@import url(../blog/cmcms.css);
html { padding: 16px; }
body { max-width: 1280px; margin: auto; }
#hs { padding: 16px; }
#hs a { display: block; float: left; margin: 16px; }
</style>
</head>
<body>
<h1 style="margin-bottom: 0;"><a class="feed-icon" href="index.rss" title="Haystack Situations feed"><img src="../blog/feed-icon.svg" alt="RSS" /></a>Haystack Situations</h1>
<div id="hs">
EOF
    for f in $(ls -1 -r ????????.png)
    do
      NUMBER="${f%.png}"
      ID="hs${NUMBER}"
      if [ -f "${NUMBER}.pdf" ]
      then
        HREF="${NUMBER}.pdf"
      else
        HREF="#${ID}"
      fi
      cat <<EOF
<a id="${ID}" href="${HREF}" title="${ITEMTITLE}${NUMBER}"><img alt="${ITEMTITLE}${NUMBER}" src="${NUMBER}.png" /></a>
EOF
    done
    cat <<EOF
<div class="separator"></div>
</div>
<div style="width: 100%; border-top: 1px solid; text-align: right;"><a href=".." title="mathr.co.uk">mathr.co.uk</a></div>
<!-- <div class="source"><a href="..." title="source">source</a></div> -->
</body></html>
EOF
  ) > index.html
) >>"${LOG}" 2>&1
